﻿using UnityEngine;
using System.Collections;

/// <summary>
/// アセットバンドルをロードして、そこから指定のシーンをロード。
/// </summary>
public class LoadSceneFromAssetBundles : MonoBehaviour {
	/// <summary>
	/// アセットバンドルのURL。
	/// </summary>
	const string SceneURL = "http://naochang.me/wp-content/entries/151022_AssetBundles/scenes";
	const string MaterialURL = "http://naochang.me/wp-content/entries/151022_AssetBundles/materials";

	/// <summary>
	/// 読み込むシーン名。
	/// </summary>
	public string sceneName;

	/// <summary>
	/// バージョン番号。
	/// </summary>
	int version = 0;

	/// <summary>
	/// Start.
	/// </summary>
	IEnumerator Start() {
		yield return StartCoroutine(this.LoadAndCache());
	}

	IEnumerator LoadAndCache() {

		//キャッシュの準備が出来るまで待機
		while (!Caching.ready)
			yield return null;
		
		// マテリアルをキャッシュもしくはウェブからダウンロード
		AssetBundle materialBundle = null;

		using (WWW www = WWW.LoadFromCacheOrDownload(LoadSceneFromAssetBundles.MaterialURL, version)) {
			yield return www;

			if (www.error != null)
				throw new UnityException("Error : " + www.error);


			materialBundle = www.assetBundle;
		}

		// シーンファイルをキャッシュもしくはウェブからダウンロード
		using (WWW www = WWW.LoadFromCacheOrDownload(LoadSceneFromAssetBundles.SceneURL, version)) {
			yield return www;

			if (www.error != null)
				throw new UnityException("Error : " + www.error);


			AssetBundle sceneBundle = www.assetBundle;

			yield return Application.LoadLevelAsync(this.sceneName);

			sceneBundle.Unload (false);
		}


		materialBundle.Unload (false);
	}
}
